<?php

	/**
	 * Swedish language file for phpPgAdmin.
	 * maintainer S. Malmqvist <samoola@slak.nu>
	 * Due to lack of SQL knowledge som translations may be wrong, mail me the correct one and ill fix it
	 *
	 * $Id: swedish.php,v 1.11 2007/04/24 11:42:07 soranzo Exp $
	 */

	// Language and character set
	$lang['applang'] = 'Swedish';
	$lang['appcharset'] = 'ISO-8859-1';
	$lang['applocale'] = 'sv_SE';
	$lang['appdbencoding'] = 'LATIN1';
	$lang['applangdir'] = 'ltr';

	// Welcome  
	$lang['strintro'] = 'Vlkommen till phpPgAdmin.';
	$lang['strppahome'] = 'phpPgAdmins Hemsida';
	$lang['strpgsqlhome'] = 'PostgreSQLs Hemsida';
	$lang['strpgsqlhome_url'] = 'http://www.postgresql.org/';
	$lang['strlocaldocs'] = 'PostgreSQLs Dokumentation (lokalt)';
	$lang['strreportbug'] = 'Rapportera ett fel';
	$lang['strviewfaq'] = 'Visa Frgor & Svar';
	$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/?page=faq';
	
	// Basic strings
	$lang['strlogin'] = 'Logga in';
	$lang['strloginfailed'] = 'Inloggningen misslyckades';
	$lang['strlogindisallowed'] = 'Inloggningen ej tillten';
	$lang['strserver'] = 'Server';
	$lang['strlogout'] = 'Logga ut';
	$lang['strowner'] = 'gare';
	$lang['straction'] = 'tgrd';
	$lang['stractions'] = 'tgrder';
	$lang['strname'] = 'Namn';
	$lang['strdefinition'] = 'Definition';
	$lang['strproperties'] = 'Egenskaper';
	$lang['strbrowse'] = 'Blddra';
	$lang['strdrop'] = 'Ta bort';
	$lang['strdropped'] = 'Borttagen';
	$lang['strnull'] = 'Ingenting';
	$lang['strnotnull'] = 'Inte Ingenting';
	$lang['strfirst'] = '<< Frsta';
	$lang['strlast'] = 'Sista >>';
	$lang['strprev'] = 'Fregende';
	$lang['strfailed'] = 'Misslyckades';
	$lang['strnext'] = 'Nsta';
	$lang['strcreate'] = 'Skapa';
	$lang['strcreated'] = 'Skapad';
	$lang['strcomment'] = 'Kommentar';
	$lang['strlength'] = 'Lngd';
	$lang['strdefault'] = 'Standardvrde';
	$lang['stralter'] = 'ndra';
	$lang['strok'] = 'OK';
	$lang['strcancel'] = 'ngra';
	$lang['strsave'] = 'Spara';
	$lang['strreset'] = 'Nollstll';
	$lang['strinsert'] = 'Infoga';
	$lang['strselect'] = 'Vlj';
	$lang['strdelete'] = 'Radera';
	$lang['strupdate'] = 'Uppdatera';
	$lang['strreferences'] = 'Referencer';
	$lang['stryes'] = 'Ja';
	$lang['strno'] = 'Nej';
	$lang['strtrue'] = 'Sant';
	$lang['strfalse'] = 'Falskt';
	$lang['stredit'] = 'Redigera';
	$lang['strcolumns'] = 'Kolumner';
	$lang['strrows'] = 'Rad(er)';
	$lang['strrowsaff'] = 'Rad(er) Pverkade.';
	$lang['strobjects'] = 'Objekt';
	$lang['strexample'] = 't. ex.';
	$lang['strback'] = 'Bakt';
	$lang['strqueryresults'] = 'Skresultat';
	$lang['strshow'] = 'Visa';
	$lang['strempty'] = 'Tom';
	$lang['strlanguage'] = 'Sprk';
	$lang['strencoding'] = 'Kodning';
	$lang['strvalue'] = 'Vrde';
	$lang['strunique'] = 'Unik';
	$lang['strprimary'] = 'Primr';
	$lang['strexport'] = 'Exportera';
	$lang['strimport'] = 'Importera';
	$lang['strsql'] = 'SQL';
	$lang['strgo'] = 'Kr';
	$lang['stradmin'] = 'Admin';
	$lang['strvacuum'] = 'Stda upp';
	$lang['stranalyze'] = 'Analysera';
	$lang['strclusterindex'] = 'Kluster';
	$lang['strclustered'] = 'Klustrat?';
	$lang['strreindex'] = 'terindexera';
	$lang['strrun'] = 'Kr';
	$lang['stradd'] = 'Lgg till';
	$lang['strinstead'] = 'Gr Istllet';
	$lang['strevent'] = 'Hndelse';
	$lang['strformat'] = 'Format';
	$lang['strwhen'] = 'Nr';
	$lang['strdata'] = 'Data';
	$lang['strconfirm'] = 'Bekrfta';
	$lang['strexpression'] = 'Uttryck';
	$lang['strellipsis'] = '...';
	$lang['strwhere'] = 'Nr';
	$lang['strexplain'] = 'Frklara';
	$lang['strfind'] = 'Sk';
	$lang['stroptions'] = 'Alternativ';
	$lang['strrefresh'] = 'Uppdatera';
	$lang['strcollapse'] = 'Frminska';
	$lang['strexpand'] = 'Utka';
	$lang['strdownload'] = 'Ladda ner';
	$lang['strdownloadgzipped'] = 'Ladda ner komprimerat med gzip';
	$lang['strinfo'] = 'Info';
	$lang['stroids'] = 'OIDs';
	$lang['stradvanced'] = 'Avancerat';
	$lang['strvariables'] = 'Variabler';
	$lang['strprocess'] = 'Process';
	$lang['strprocesses'] = 'Processer';
	$lang['strsetting'] = 'Instllning';
	$lang['strparameters'] = 'Parametrar';

	// Error handling
	$lang['strnotloaded'] = 'Du har inte kompilerat in korrekt databasstd i din PHP-installation.';
	$lang['strbadconfig'] = 'Din config.inc.php r ej uppdaterad. Du mste terskapa den frn den nya config.inc.php-dist.';
	$lang['strbadencoding'] = 'Misslyckades att stta klientkodning i databasen.';
	$lang['strbadschema'] = 'Otilltet schema angett.';
	$lang['strinstatement'] = 'I pstende:';
	$lang['strsqlerror'] = 'SQL fel:';
	$lang['strinvalidparam'] = 'Otilltna scriptparametrar.';
	$lang['strnodata'] = 'Hittade inga rader.';
	$lang['strnoobjects'] = 'Hittade inga objekt.';
	$lang['strrownotunique'] = 'Ingen unik nyckel fr denna rad.';
	$lang['strnoreportsdb'] = 'Du har inte skapat ngon rapportdatabas. Ls filen INSTALL fr instruktioner.';

	// Tables
	$lang['strtable'] = 'Tabell';
	$lang['strtables'] = 'Tabeller';
	$lang['strshowalltables'] = 'Visa alla tabeller';
	$lang['strnotables'] = 'Hittade inga tabeller.';
	$lang['strnotable'] = 'Hittade ingen tabell.';
	$lang['strcreatetable'] = 'Skapa tabell';
	$lang['strtablename'] = 'Tabellnamn';
	$lang['strtableneedsname'] = 'Du mste ge ett namn till din tabell.';
	$lang['strtableneedsfield'] = 'Du mste ange minst ett flt.';
	$lang['strtableneedscols'] = 'tabeller krver ett tilltet antal kolumner.';
	$lang['strtablecreated'] = 'Tabell skapad.';
	$lang['strtablecreatedbad'] = 'Misslyckades med att skapa Tabell.';
	$lang['strconfdroptable'] = 'r du sker p att du vill ta bort tabellen "%s"?';
	$lang['strtabledropped'] = 'Tabellen borttagen.';
	$lang['strinsertrow'] = 'Infoga rad';
	$lang['strtabledroppedbad'] = 'Misslyckades med att ta bort tabellen.';
	$lang['strrowinserted'] = 'Rad infogad.';
	$lang['strconfemptytable'] = 'r du sker p att du vill tmma tabellen "%s"?';
	$lang['strrowupdated'] = 'Rad uppdaterad.';
	$lang['strrowinsertedbad'] = 'Misslyckades att infoga rad.';
	$lang['strtableemptied'] = 'Tabellen tmd.';
	$lang['strrowupdatedbad'] = 'Misslyckades att uppdatera rad.';
	$lang['streditrow'] = 'ndra rad';
	$lang['strrowdeleted'] = 'Rad raderad.';
	$lang['strrowdeletedbad'] = 'Misslyckades att radera rad.';
	$lang['strfield'] = 'Flt';
	$lang['strconfdeleterow'] = 'r du sker p att du vill ta bort denna rad?';
	$lang['strnumfields'] = 'Antal flt';
	$lang['strsaveandrepeat'] = 'Infoga & Upprepa';
	$lang['strtableemptiedbad'] = 'Misslyckades med att tmma tabellen';
	$lang['strdeleterow'] = 'Radera rad';
	$lang['strfields'] = 'Flt';
	$lang['strfieldneedsname'] = 'Du mste namnge fltet';
	$lang['strcolumndropped'] = 'Kolumn raderad.';
	$lang['strselectallfields'] = 'Vlj alla flt';
	$lang['strselectneedscol'] = 'Du mste visa minst en kolumn';
	$lang['strselectunary'] = 'Unra operander kan ej ha vrden.';
	$lang['strcolumnaltered'] = 'Kolumn ndrad.';
	$lang['straltercolumn'] = 'ndra kolumn';
	$lang['strcolumnalteredbad'] = 'Misslyckades att ndra kolumn.';
	$lang['strconfdropcolumn'] = 'r du sker p att du vill radera kolumn "%s" frn tabell "%s"?';
	$lang['strcolumndroppedbad'] = 'Misslyckades att radera kolumn.';
	$lang['straddcolumn'] = 'Lgg till kolumn';
	$lang['strcolumnadded'] = 'Kolumn inlagd.';
	$lang['strcolumnaddedbad'] = 'Misslyckades att lgga till kolumne.';
	$lang['strcascade'] = 'KASKAD';
	$lang['strdataonly'] = 'Endast Data';
	$lang['strtablealtered'] = 'Tabell ndrad.';
	$lang['strtablealteredbad'] = 'Misslyckades att ndra tabell.';
	
	// Users
	$lang['struser'] = 'Anvndare';
	$lang['strusers'] = 'Anvndare';
	$lang['strusername'] = 'Anvndarnamn';
	$lang['strpassword'] = 'Lsenord';
	$lang['strsuper'] = 'Superanvndare?';
	$lang['strcreatedb'] = 'Skapa Databas?';
	$lang['strexpires'] = 'Utgngsdatum';
	$lang['strsessiondefaults'] = 'Sessionsinstllningar';
	$lang['strnewname'] = 'Nytt namn';
	$lang['strnousers'] = 'Hittade inga anvndare.';
	$lang['strrename'] = 'Dp om';
	$lang['struserrenamed'] = 'Anvndarnamn ndrat.';
	$lang['struserrenamedbad'] = 'Misslyckades att dpa om anvndare.';
	$lang['struserupdated'] = 'Anvndare uppdaterad.';
	$lang['struserupdatedbad'] = 'Misslyckades att uppdatera anvndare.';
	$lang['strshowallusers'] = 'Visa alla anvndare';
	$lang['strcreateuser'] = 'Skapa anvndare';
	$lang['struserneedsname'] = 'Du mste namnge anvndaren.';
	$lang['strconfdropuser'] = 'r du sker p att du vill radera anvndaren "%s"?';
	$lang['strusercreated'] = 'Anvndare skapad.';
	$lang['strusercreatedbad'] = 'Misslyckades att skapa anvndare.';
	$lang['struserdropped'] = 'Anvndare raderad.';
	$lang['struserdroppedbad'] = 'Misslyckades att radera anvndare.';
	$lang['straccount'] = 'Konton';
	$lang['strchangepassword'] = 'ndra lsenord';
	$lang['strpasswordchanged'] = 'Lsenord ndrat.';
	$lang['strpasswordchangedbad'] = 'Misslyckades att ndra lsenord.';
	$lang['strpasswordshort'] = 'Fr f tecken i lsenordet.';
	$lang['strpasswordconfirm'] = 'Lsenordet r inte samma som bekrftelsen.';
	$lang['strgroup'] = 'Grupp';
	$lang['strgroups'] = 'Grupper';
	$lang['strnogroup'] = 'Hittade ej grupp.';
	$lang['strnogroups'] = 'Hittade inga grupper.';
	$lang['strcreategroup'] = 'Skapa grupp';
	$lang['strshowallgroups'] = 'Visa alla grupper';
	$lang['strgroupneedsname'] = 'Du mste namnge din grupp.';
	$lang['strgroupcreated'] = 'Grupp skapad.';
	$lang['strgroupdropped'] = 'Grupp raderad.';
	$lang['strgroupcreatedbad'] = 'Misslyckades att skapa grupp.';	
	$lang['strconfdropgroup'] = 'r du sker p att du vill radera grupp "%s"?';
	$lang['strprivileges'] = 'Rttigheter';
	$lang['strgrant'] = 'Tillt';
	$lang['strgranted'] = 'Rttigheter ndrade.';
	$lang['strgroupdroppedbad'] = 'Misslyckades att radera grupp.';
	$lang['straddmember'] = 'Lgg till medlem';
	$lang['strmemberadded'] = 'Medlem inlagd.';
	$lang['strmemberaddedbad'] = 'Misslyckades att lgga till medlem.';
	$lang['strdropmember'] = 'Radera medlem';
	$lang['strconfdropmember'] = 'r du sker p att du vill radera medlem "%s" frn gruppen "%s"?';
	$lang['strmemberdropped'] = 'Medlem raderad.';
	$lang['strmemberdroppedbad'] = 'Misslyckades att radera medlem.';
	$lang['strprivilege'] = 'Rttighet';
	$lang['strnoprivileges'] = 'Detta objekt har standard garrttigheter.';
	$lang['strmembers'] = 'Medelemmar';
	$lang['strrevoke'] = 'Ta tillbaka';
	$lang['strgrantbad'] = 'Du mste ange minst en anvndare eller grupp och minst en rttighet.';
	$lang['strgrantfailed'] = 'Misslyckades att ndra rttigheter.';
	$lang['stralterprivs'] = 'ndra rttigheter';
	$lang['strdatabase'] = 'Databas';
	$lang['strdatabasedropped'] = 'Databas raderad.';
	$lang['strdatabases'] = 'Databaser';
	$lang['strentersql'] = 'Ange SQL att kra:';
	$lang['strgrantor'] = 'Tillstndsgivare';
	$lang['strasterisk'] = '*';
	$lang['strshowalldatabases'] = 'Visa alla databaser';
	$lang['strnodatabase'] = 'Hittade ingen databas.';
	$lang['strnodatabases'] = 'Hittade inga databaser.';
	$lang['strcreatedatabase'] = 'Skapa databas';
	$lang['strdatabasename'] = 'Databasnamn';
	$lang['strdatabaseneedsname'] = 'Du mste namnge databasen.';
	$lang['strdatabasecreated'] = 'Databas skapad.';
	$lang['strdatabasecreatedbad'] = 'Misslyckades att skapa databas.';	
	$lang['strconfdropdatabase'] = 'r du sker p att du vill radera databas "%s"?';
	$lang['strdatabasedroppedbad'] = 'Misslyckades att radera databas.';
	$lang['strsqlexecuted'] = 'SQL-kommando utfrt.';
	$lang['strvacuumgood'] = 'Uppstdning utfrd.';
	$lang['strvacuumbad'] = 'Uppstdning misslyckades.';
	$lang['stranalyzegood'] = 'Analysen lyckades.';
	$lang['stranalyzebad'] = 'Analysen misslyckades.';
	$lang['strstructureonly'] = 'Endast struktur';
	$lang['strstructureanddata'] = 'Struktur och data';

	// Views
	$lang['strview'] = 'Vy';
	$lang['strviews'] = 'Vyer';
	$lang['strshowallviews'] = 'Visa alla vyer';
	$lang['strnoview'] = 'Hittade ingen vy.';
	$lang['strnoviews'] = 'Hittade inga vyer.';
	$lang['strcreateview'] = 'Skapa vy';
	$lang['strviewname'] = 'Vynamn';
	$lang['strviewneedsname'] = 'Du mste namnge Vy.';
	$lang['strviewneedsdef'] = 'Du mste ange en definition fr din vy.';
	$lang['strviewcreated'] = 'Vy skapad.';
	$lang['strviewcreatedbad'] = 'Misslyckades att skapa vy.';
	$lang['strconfdropview'] = 'r du sker p att du vill radera vyn "%s"?';
	$lang['strviewdropped'] = 'Vy raderad.';
	$lang['strviewdroppedbad'] = 'Misslyckades att radera vy.';
	$lang['strviewupdated'] = 'Vy uppdaterad.';
	$lang['strviewupdatedbad'] = 'Misslyckades att uppdatera vy.';
	$lang['strviewlink'] = 'Lnkade nycklar';
	$lang['strviewconditions'] = 'Ytterligare villkor';

	// Sequences
	$lang['strsequence'] = 'Sekvens';
	$lang['strsequences'] = 'Sekvenser';
	$lang['strshowallsequences'] = 'Visa alla sekvenser';
	$lang['strnosequence'] = 'Hittade ingen sekvens.';
	$lang['strnosequences'] = 'Hittade inga sekvenser.';
	$lang['strcreatesequence'] = 'Skapa sekvens';
	$lang['strlastvalue'] = 'Senaste vrde';
	$lang['strincrementby'] = 'ka med';
	$lang['strstartvalue'] = 'Startvrde';
	$lang['strmaxvalue'] = 'Strsta vrde';
	$lang['strminvalue'] = 'Minsta vrde';
	$lang['strcachevalue'] = 'Vrde p cache';
	$lang['strlogcount'] = 'Rkna log';
	$lang['striscycled'] = 'r upprepad?';
	$lang['strsequenceneedsname'] = 'Du mste ge ett namn till din sekvens.';
	$lang['strsequencecreated'] = 'Sekvens skapad.';
	$lang['strsequencecreatedbad'] = 'Misslyckades att skapa sekvens.'; 
	$lang['strconfdropsequence'] = 'r du sker p att du vill radera sekvensen "%s"?';
	$lang['strsequencedropped'] = 'Sekvensen borrtagen.';
	$lang['strsequencedroppedbad'] = 'Misslyckades att radera sekvens.';

	// Indexes
	$lang['strindex'] = 'Index';
	$lang['strindexes'] = 'Index';
	$lang['strindexname'] = 'Indexnamn';
	$lang['strshowallindexes'] = 'Visa alla index';
	$lang['strnoindex'] = 'Hittade inget index.';
	$lang['strsequencereset'] = 'Nollstll sekvens.';
	$lang['strsequenceresetbad'] = 'Misslyckades att nollstlla sekvens.';
	$lang['strnoindexes'] = 'Hittade inga index.';
	$lang['strcreateindex'] = 'Skapa index';
	$lang['strindexname'] = 'Indexnamn';
	$lang['strtabname'] = 'Tabellnamn';
	$lang['strcolumnname'] = 'Kolumnnamn';
	$lang['strindexneedsname'] = 'Du mste ge ett namn fr ditt index';
	$lang['strindexneedscols'] = 'Det krvs ett giltigt antal kolumner fr index.';
	$lang['strindexcreated'] = 'Index skapat';
	$lang['strindexcreatedbad'] = 'Misslyckades att skapa index.';
	$lang['strconfdropindex'] = 'r du sker p att du vill radera index "%s"?';
	$lang['strindexdropped'] = 'Index raderat.';
	$lang['strindexdroppedbad'] = 'Misslyckades att radera index.';
	$lang['strkeyname'] = 'Nyckelvrdesnamn';
	$lang['struniquekey'] = 'Unikt nyckelvrde';
	$lang['strprimarykey'] = 'Primrnyckel';
 	$lang['strindextype'] = 'Typ av index';
	$lang['strindexname'] = 'Indexnamn';
	$lang['strtablecolumnlist'] = 'Tabellkolumner';
	$lang['strindexcolumnlist'] = 'Indexkolumner';
	$lang['strconfcluster'] = 'r du sker p att du vill klustra "%s"?';
	$lang['strclusteredgood'] = 'Klustring avslutad.';
	$lang['strclusteredbad'] = 'Klustring misslyckades.';

	// Rules
	$lang['strrules'] = 'Regler';
	$lang['strrule'] = 'Regel';
	$lang['strshowallrules'] = 'Visa alla regler';
	$lang['strnorule'] = 'Hittade ingen regel.';
	$lang['strnorules'] = 'Hittade inga regler.';
	$lang['strcreaterule'] = 'Skapa regel';
	$lang['strrulename'] = 'Regelnamn';
	$lang['strruleneedsname'] = 'Du mste ge ett namn till din regel.';
	$lang['strrulecreated'] = 'Regel skapad.';
	$lang['strrulecreatedbad'] = 'Misslyckades att skapa regel.';
	$lang['strconfdroprule'] = 'r du sker p att du vill radera regel "%s" fr "%s"?';
	$lang['strruledropped'] = 'Regel raderat.';
	$lang['strruledroppedbad'] = 'Misslyckades att radera regel.';

	// Constraints
	$lang['strconstraints'] = 'Begrnsningar';
	$lang['strshowallconstraints'] = 'Visa alla begrnsningar';
	$lang['strnoconstraints'] = 'Hittade inga begrnsningar.';
	$lang['strcreateconstraint'] = 'Skapa begrnsning';
	$lang['strconstraintcreated'] = 'Begrnsning skapad.';
	$lang['strconstraintcreatedbad'] = 'Misslyckades att skapa begrnsning.';
	$lang['strconfdropconstraint'] = 'r du sker p att du vill radera begrnsning "%s" fr "%s"?';
	$lang['strconstraintdropped'] = 'Begrnsning raderad.';
	$lang['strconstraintdroppedbad'] = 'Misslyckades att radera begrnsning.';
	$lang['straddcheck'] = 'Lgg till en koll';
	$lang['strcheckneedsdefinition'] = 'En kollbegrnsning behver definieras.';
	$lang['strcheckadded'] = 'Kollbegrnsning inlagd.';
	$lang['strcheckaddedbad'] = 'Misslyckades att lgga till en koll.';
	$lang['straddpk'] = 'Lgg till primrnyckel';
	$lang['strpkneedscols'] = 'Primrnyckel behver minst en kolumn.';
	$lang['strpkadded'] = 'Primrnyckel inlagd.';
	$lang['strpkaddedbad'] = 'Misslyckades att lgga till primrnyckel.';
	$lang['stradduniq'] = 'Lgg till Unikt nyckelvrde';
	$lang['struniqneedscols'] = 'Unikt nyckelvrde behver minst en kolumn.';
	$lang['struniqadded'] = 'Unikt nyckelvrde inlagt.';
	$lang['struniqaddedbad'] = 'Misslyckades att lgga till unikt nyckelvrde.';
	$lang['straddfk'] = 'Lgg till utomstende nyckel';
	$lang['strfkneedscols'] = 'Utomstende nyckel behver minst en kolumn.';
	$lang['strfkneedstarget'] = 'Utomstende nycket behver en mltabell.';
	$lang['strfkadded'] = 'Utomstende nyckel inlagd.';
	$lang['strfkaddedbad'] = 'Misslyckades att lgga till utomstende nyckel.';
	$lang['strfktarget'] = 'Mltabell';
	$lang['strfkcolumnlist'] = 'Kolumner i nyckel';
	$lang['strondelete'] = 'VID RADERING';
	$lang['stronupdate'] = 'VID UPPDATERING';

	// Functions
	$lang['strfunction'] = 'Funktion';
	$lang['strfunctions'] = 'Funktioner';
	$lang['strshowallfunctions'] = 'Visa alla funktioner';
	$lang['strnofunction'] = 'Hittade ingen funktion.';
	$lang['strnofunctions'] = 'Hittade inga funktioner.';
	$lang['strcreatefunction'] = 'Skapa funktion';
	$lang['strfunctionname'] = 'Funktionsnamn';
	$lang['strreturns'] = 'terger';
	$lang['strarguments'] = 'Argument';
	$lang['strfunctionneedsname'] = 'Du mste namnge din funktion.';
	$lang['strfunctionneedsdef'] = 'Du mste definiera din funktion.';
	$lang['strfunctioncreated'] = 'Funktion skapad.';
	$lang['strfunctioncreatedbad'] = 'Misslyckades att skapa funktion.';
	$lang['strconfdropfunction'] = 'r du sker p att du vill radera funktionen "%s"?';
	$lang['strproglanguage'] = 'Programmeringssprk';
	$lang['strfunctiondropped'] = 'Funktionen raderad.';
	$lang['strfunctiondroppedbad'] = 'Misslyckades att radera funktion.';
	$lang['strfunctionupdated'] = 'Funktion uppdaterad.';
	$lang['strfunctionupdatedbad'] = 'Misslyckades att uppdatera funktion.';

	// Triggers
	$lang['strtrigger'] = 'Mekanism';
	$lang['strtriggers'] = 'Mekanismer';
	$lang['strshowalltriggers'] = 'Visa alla Mekanismer';
	$lang['strnotrigger'] = 'Hittade ingen mekanism.';
	$lang['strnotriggers'] = 'Hittade inga mekanismer.';
	$lang['strcreatetrigger'] = 'Skapa mekanism';
	$lang['strtriggerneedsname'] = 'Du mste namnge din mekanism.';
	$lang['strtriggerneedsfunc'] = 'Du mste specificera en funktion fr din mekanism.';
	$lang['strtriggercreated'] = 'Mekanism skapad.';
	$lang['strtriggerdropped'] = 'Mekanism raderad.';
	$lang['strtriggercreatedbad'] = 'Misslyckades att skapa mekanism.';
	$lang['strconfdroptrigger'] = 'r du sker p att du vill radera mekanismen "%s" p "%s"?';
	$lang['strtriggerdroppedbad'] = 'Misslyckades att radera mekanism.';
	
	// Types
	$lang['strtype'] = 'Typ';
	$lang['strstorage'] = 'Lagring';
	$lang['strtriggeraltered'] = 'Mekanism ndrad.';
	$lang['strtriggeralteredbad'] = 'Misslyckades att ndra mekanism.';
	$lang['strtypes'] = 'Typer';
	$lang['strtypeneedslen'] = 'Du mste ange typens lngd.';
	$lang['strshowalltypes'] = 'Visa alla typer';
	$lang['strnotype'] = 'Hittade ingen typ.';
	$lang['strnotypes'] = 'Hittade inga typer.';
	$lang['strcreatetype'] = 'Skapa typ';
	$lang['strtypename'] = 'Namn p typen';
	$lang['strinputfn'] = 'Infogande funktion';
	$lang['stroutputfn'] = 'Funktion fr utvrden';
	$lang['strpassbyval'] = 'Genomgtt utvrdering?';
	$lang['stralignment'] = 'Justering';
	$lang['strelement'] = 'Element';
	$lang['strdelimiter'] = 'Avgrnsare';
	$lang['strtypeneedsname'] = 'Du mste namnge din typ.';
	$lang['strtypecreated'] = 'Typ skapad';
	$lang['strtypecreatedbad'] = 'Misslyckades att skapa typ.';
	$lang['strconfdroptype'] = 'r du sker p att du vill radera typen "%s"?';
	$lang['strtypedropped'] = 'Typ raderad.';
	$lang['strtypedroppedbad'] = 'Misslyckades att radera typ.';

	// Schemas
	$lang['strschema'] = 'Schema';
	$lang['strschemas'] = 'Scheman';
	$lang['strshowallschemas'] = 'Visa alla scheman';
	$lang['strnoschema'] = 'Hittade inget schema.';
	$lang['strnoschemas'] = 'Hittade inga scheman.';
	$lang['strcreateschema'] = 'Skapa Schema';
	$lang['strschemaname'] = 'Schemanamn';
	$lang['strschemaneedsname'] = 'Du mste namnge ditt Schema.';
	$lang['strschemacreated'] = 'Schema skapat';
	$lang['strschemacreatedbad'] = 'Misslyckades att skapa schema.';
	$lang['strconfdropschema'] = 'r du sker p att du vill radera schemat "%s"?';
	$lang['strschemadropped'] = 'Schema raderat.';
	$lang['strschemadroppedbad'] = 'Misslyckades att radera schema.';

	// Reports
	$lang['strreport'] = 'Rapport';
	$lang['strreports'] = 'Rapporter';
	$lang['strshowallreports'] = 'Visa alla rapporter';
	$lang['strtopbar'] = '%s krs p %s:%s -- Du r inloggad som anvndare "%s"';
	$lang['strtimefmt'] = 'jS M, Y g:iA';
	$lang['strnoreports'] = 'Hittade inga rapporter.';
	$lang['strcreatereport'] = 'Skapa rapport';
	$lang['strreportdropped'] = 'Rapport skapad.';
	$lang['strreportcreated'] = 'Rapport sparad.';
	$lang['strreportneedsname'] = 'Du mste namnge din rapport.';
	$lang['strreportcreatedbad'] = 'Misslyckades att spara rapport.';
	$lang['strreportdroppedbad'] = 'Misslyckades att skapa rapport.';
	$lang['strconfdropreport'] = 'r du sker p att du vill radera rapporten "%s"?';
	$lang['strreportneedsdef'] = 'Du mste ange din SQL-frga.';
	
	// Domains
	$lang['strdomain'] = 'Domn';
	$lang['strdomains'] = 'Domner';
	$lang['strshowalldomains'] = 'Visa alla domner';
	$lang['strnodomains'] = 'Hittade inga domner.';
	$lang['strcreatedomain'] = 'Skapa domn';
	$lang['strdomaindropped'] = 'Domn raderad.';
	$lang['strdomaindroppedbad'] = 'Misslyckades att radera domn.';
	$lang['strconfdropdomain'] = 'r du sker p att du vill radera domnen "%s"?';
	$lang['strdomainneedsname'] = 'Du mste ange ett domnnamn.';
	$lang['strdomaincreated'] = 'Domn skapad.';
	$lang['strdomaincreatedbad'] = 'Misslyckades att skapa domn.';
	$lang['strdomainaltered'] = 'Domn ndrad.';
	$lang['strdomainalteredbad'] = 'Misslyckades att ndra domn.';
	
	// Operators
	$lang['stroperator'] = 'Operand';
	$lang['stroperators'] = 'Operander';
	$lang['strshowalloperators'] = 'Visa alla operander';
	$lang['strnooperator'] = 'Hittade ingen operand.';
	$lang['strnooperators'] = 'Hittade inga operander.';
	$lang['strcreateoperator'] = 'Skapa operand';
	$lang['strleftarg'] = 'Arg Typ Vnster';
	$lang['strrightarg'] = 'Arg Typ Hger';
	$lang['strcommutator'] = 'Vxlare';
	$lang['strnegator'] = 'Negerande';
	$lang['strrestrict'] = 'Sprra';
	$lang['strjoin'] = 'Sl ihop';
	$lang['strhashes'] = 'Hashtabeller';
	$lang['strmerges'] = 'Sammanslagningar';
	$lang['strleftsort'] = 'Sortera vnster';
	$lang['strrightsort'] = 'Sortera hger';
	$lang['strlessthan'] = 'Mindre n';
	$lang['strgreaterthan'] = 'Strre n';
	$lang['stroperatorneedsname'] = 'Du mste namnge operanden.';
	$lang['stroperatorcreated'] = 'Operand skapad';
	$lang['stroperatorcreatedbad'] = 'Misslyckades att skapa operand.';
	$lang['strconfdropoperator'] = 'r du sker p att du vill radera operanden "%s"?';
	$lang['stroperatordropped'] = 'Operand raderad.';
	$lang['stroperatordroppedbad'] = 'Misslyckades att radera operand.';

	// Casts
	$lang['strcasts'] = 'Typomvandlingar';
	$lang['strnocasts'] = 'Hittade inga typomvandlingar.';
	$lang['strsourcetype'] = 'Klltyp';
	$lang['strtargettype'] = 'Mltyp';
	$lang['strimplicit'] = 'Implicit';
	$lang['strinassignment'] = 'Tilldelat i';
	$lang['strbinarycompat'] = '(Binrt kompatibel)';
	
	// Conversions
	$lang['strconversions'] = 'Omkodningar';
	$lang['strnoconversions'] = 'Hittade inga omkodningar.';
	$lang['strsourceencoding'] = 'Kllkodning';
	$lang['strtargetencoding'] = 'Mlkodning';
	
	// Languages
	$lang['strlanguages'] = 'Sprk';
	$lang['strnolanguages'] = 'Hittade inga sprk.';
	$lang['strtrusted'] = 'Plitlig(a)';
	
	// Info
	$lang['strnoinfo'] = 'Ingen information tillgnglig.';
	$lang['strreferringtables'] = 'Refererande tabeller';
	$lang['strparenttables'] = 'Ovanstende tabeller';
	$lang['strchildtables'] = 'Underliggande tabeller';

	// Aggregates
	$lang['straggregates'] = 'Sammanslagningar';
	$lang['strnoaggregates'] = 'Hittade inga sammanslagningar.';
	$lang['stralltypes'] = '(Alla typer)';
	
	// Operator Classes
	$lang['stropclasses'] = 'Op Klasser';
	$lang['strnoopclasses'] = 'Hittade inga operandklasser.';
	$lang['straccessmethod'] = 'Kopplingsmetod';
	
	// Stats and performance
	$lang['strrowperf'] = 'Radprestanda';
	$lang['strioperf'] = 'I/O Prestanda';
	$lang['stridxrowperf'] = 'Index Radprestanda';
	$lang['stridxioperf'] = 'Index I/O Prestanda';
	$lang['strpercent'] = '%';
	$lang['strsequential'] = 'Sekventiell';
	$lang['strscan'] = 'Scanna';
	$lang['strread'] = 'Ls';
	$lang['strfetch'] = 'Hmta';
	$lang['strheap'] = 'Bunt';
	$lang['strtoast'] = 'Brnn';
	$lang['strtoastindex'] = 'Brnn Index';
	$lang['strcache'] = 'Cache';
	$lang['strdisk'] = 'Disk';
	$lang['strrows2'] = 'Rader';

	// Miscellaneous
	$lang['strtopbar'] = '%s Krs p %s:%s -- Du r inloggad som anvndare "%s", %s';
	$lang['strtimefmt'] = 'jS M, Y g:iA';
	$lang['strhelp'] = 'Hjlp';

?>
